@@ -58,3 +58,10 @@ anytime(c(NA, NaN, Inf, as.numeric(as.POSIXct("2016-09-01 10:11:12"))))
 
 cat("\n")                               # special case of no separators
 anytime(c("20160911", "20160911 1011", "20160911 101112", "20160911 101112.345678"))
+
+
+anytime("NA") 				# String NA
+anytime(Sys.time())                     # POSIXt pass-through
+anytime(Sys.Date())			# Date pass-through
+utcdate(Sys.Date())                     # Date pass-through
+try(anytime(TRUE))                      # tickles unsupported type -- and exception, hence try()
